#!/usr/bin/env python
import libcagen
import argparse
import os.path

from mako.template import Template

parser = argparse.ArgumentParser(prog = "cagen-list", description="make markdown list of entries")
parser.add_argument("template", type=str, help="Mako template to use")
parser.add_argument("--group_by", type=str, help="group by an specific key. Eg. --group_by date. The field passed in --group_by is a key of metadata.")
parser.add_argument("--title", type=str, default='List', help="the title of the generated list document. 'list' by default")
parser.add_argument("list", type=str, nargs='*', help="the file list of entries. Eg. this.md that.md ... Missing files are ignored")
args = parser.parse_args()

collection = libcagen.Collection(args.list)
# pass all parameters to desired template
if os.path.exists(args.template):
    template = Template(filename=args.template, strict_undefined=True)
    mysearchlist = {'collection': collection, 'title': args.title, 'group_by': args.group_by}
    print(template.render(**mysearchlist))



#!/usr/bin/env python
import argparse

maketemplate = """
# Default template
TMPHTML5 = templates/schema.tmpl

# Select all markdowns file except index.md
MARKDOWNS = $(shell find . -type f -name "*.md" ! -name "index.md")

# Replace the extension.
# By default HTML5
MARKDOWNS_HTML5 = $(MARKDOWNS:.md=.html)

# Extra metadata. Use if you want and edit freely
REPOSITORY = "https://git.sr.ht/~somenxavierb/cmpalgorithms"
REVISIONNUMBER = $(shell git log --format=oneline $<  | wc -l)

# Commands

SSG = ./cagen.py

# Processing

.PHONY: all clean

all: $(MARKDOWNS_HTML5)

# .MD.HTML -> .HTML
%.html: %.md
\t$(SSG) $< $@ $(TMPHTML5) --metadata sourcefile="$(shell echo $<)"

clean:
\trm $(MARKDOWNS_HTML5)
"""


parser = argparse.ArgumentParser(prog = "cagen-make", description="creates a Makefile file for using GNU Make to generate HTML5 files using cagen")
parser.add_argument("--init", action='store_true', help="creates the Makefile")
args = parser.parse_args()

if args.init:
    with open("Makefile", "w") as f:
        f.write(maketemplate)
else:
    print("See --help for hints")

